"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsNull = exports.IS_NULL = void 0;
const class_validator_1 = require("class-validator");
const is_null_predicate_1 = require("./is-null.predicate");
/** @hidden */
exports.IS_NULL = 'isNull';
/**
 * Checks if the given value is `null`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is null (but not undefined).
 * @IsNull()
 * value: null
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
function IsNull(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_NULL,
        validator: {
            validate: (value, _arguments) => (0, is_null_predicate_1.isNull)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be null`, options),
        },
    }, options);
}
exports.IsNull = IsNull;
